@@ -6,7 +6,10 @@ import unittest
 from monasca_agent.common.keystone import Keystone
 
 port_used = 0
+
+
 class TestKeystone(unittest.TestCase):
+
     def setUp(self):
         global port_used
         # Create a server socket so the htto check config gets created
@@ -34,14 +37,14 @@ class TestKeystone(unittest.TestCase):
         self.assertEqual(http_instance['match_pattern'], '.*OK.*')
 
         processes = config['process']['instances']
-        self.assertEqual(processes[0]['search_string'], ['nose'])
+        self.assertEqual(processes[0]['search_string'], ['testr'])
 
     def test_override_values(self):
         """ Test overriding values using args works
         """
         url = 'http://localhost:{0}/othercheck'.format(port_used)
         pattern = 'CHECK.*'
-        args = 'process_names=tox,nose service_api_url='
+        args = 'process_names=tox,testr service_api_url='
         args += ' service_api_url=' + url
         args += ' search_pattern=' + pattern
         test_plugin = TestPlugin('.', args=args)
@@ -54,7 +57,8 @@ class TestKeystone(unittest.TestCase):
 
         processes = config['process']['instances']
         self.assertEqual(processes[0]['search_string'], ['tox'])
-        self.assertEqual(processes[1]['search_string'], ['nose'])
+        self.assertEqual(processes[1]['search_string'], ['testr'])
+
 
 class TestPlugin(monasca_setup.detection.ServicePlugin):
 
@@ -68,8 +72,8 @@ class TestPlugin(monasca_setup.detection.ServicePlugin):
             'args': args,
             'template_dir': template_dir,
             'overwrite': overwrite,
-            'service_name': 'object-storage',
-            'process_names': ['nose'],
+            'service_name': 'os-testr',
+            'process_names': ['testr'],
             'service_api_url': url,
             'search_pattern': '.*OK.*'
         }
